import {Component, inject} from '@angular/core';
import {
  MAT_DIALOG_DATA,
  MatDialogActions,
  MatDialogContent,
  MatDialogRef,
  MatDialogTitle
} from "@angular/material/dialog";
import {FormsModule, ReactiveFormsModule} from "@angular/forms";
import QualificationService from "../../services/qualification.service";
import {MatButton} from "@angular/material/button";

@Component({
  selector: 'app-delete-qualification',
  imports: [
    FormsModule,
    MatDialogContent,
    MatDialogTitle,
    ReactiveFormsModule,
    MatDialogActions,
    MatButton
  ],
  templateUrl: './delete.component.html',
  standalone: true,
  styleUrl: './delete.component.css'
})
export class DeleteComponent {
  public id: number = inject(MAT_DIALOG_DATA);
  public apiError: string | null = null;

  private qualificationService: QualificationService = inject(QualificationService);
  private dialogRef: MatDialogRef<DeleteComponent> = inject(MatDialogRef);

  delete() {
    this.qualificationService.delete(this.id).subscribe({
      next: () => {
        this.dialogRef.close(true);
      },
      error: (error) => {
        console.error('Error deleting qualification:', error);

        this.apiError = 'API Error';
      }
    });
  }

  closeModal() {
    this.dialogRef.close(false);
  }
}
